@@ -20,6 +20,7 @@ namespace stan {
     // components of abstract syntax tree
     struct array_literal;
     struct assignment;
+    struct assgn;
     struct binary_op;
     struct conditional_statement;
     struct distribution;
@@ -33,6 +34,7 @@ namespace stan {
     struct identifier;
     struct increment_log_prob_statement;
     struct index_op;
+    struct index_op_sliced;
     struct int_literal;
     struct inv_var_decl;
     struct matrix_var_decl;
@@ -75,7 +77,7 @@ namespace stan {
       base_expr_type base_type_;
       size_t num_dims_;
       expr_type();
-      expr_type(const base_expr_type base_type);
+      expr_type(const base_expr_type base_type);  // NOLINT(runtime/explicit)
       expr_type(const base_expr_type base_type,
                 size_t num_dims);
       bool operator==(const expr_type& et) const;
@@ -192,7 +194,6 @@ namespace stan {
                  const std::vector<statement>& stmts);
     };
 
-
     struct distribution {
       std::string family_;
       std::vector<expression> args_;
@@ -207,6 +208,7 @@ namespace stan {
       expr_type operator()(const fun& e) const;
       expr_type operator()(const integrate_ode& e) const;
       expr_type operator()(const index_op& e) const;
+      expr_type operator()(const index_op_sliced& e) const;
       expr_type operator()(const binary_op& e) const;
       expr_type operator()(const unary_op& e) const;
       // template <typename T> expr_type operator()(const T& e) const;
@@ -224,6 +226,7 @@ namespace stan {
                              boost::recursive_wrapper<integrate_ode>,
                              boost::recursive_wrapper<fun>,
                              boost::recursive_wrapper<index_op>,
+                             boost::recursive_wrapper<index_op_sliced>,
                              boost::recursive_wrapper<binary_op>,
                              boost::recursive_wrapper<unary_op> >
       expression_t;
@@ -232,17 +235,18 @@ namespace stan {
       expression(const expression& e);
 
       // template <typename Expr> expression(const Expr& expr);
-      expression(const nil& expr);
-      expression(const int_literal& expr);
-      expression(const double_literal& expr);
-      expression(const array_literal& expr);
-      expression(const variable& expr);
-      expression(const fun& expr);
-      expression(const integrate_ode& expr);
-      expression(const index_op& expr);
-      expression(const binary_op& expr);
-      expression(const unary_op& expr);
-      expression(const expression_t& expr_);
+      expression(const nil& expr);  // NOLINT(runtime/explicit)
+      expression(const int_literal& expr);  // NOLINT(runtime/explicit)
+      expression(const double_literal& expr);  // NOLINT(runtime/explicit)
+      expression(const array_literal& expr);  // NOLINT(runtime/explicit)
+      expression(const variable& expr);  // NOLINT(runtime/explicit)
+      expression(const fun& expr);  // NOLINT(runtime/explicit)
+      expression(const integrate_ode& expr);  // NOLINT(runtime/explicit)
+      expression(const index_op& expr);  // NOLINT(runtime/explicit)
+      expression(const index_op_sliced& expr);  // NOLINT(runtime/explicit)
+      expression(const binary_op& expr);  // NOLINT(runtime/explicit)
+      expression(const unary_op& expr);  // NOLINT(runtime/explicit)
+      expression(const expression_t& expr_);  // NOLINT(runtime/explicit)
 
       expr_type expression_type() const;
       int total_dims() const;
@@ -262,28 +266,26 @@ namespace stan {
       printable_t;
 
       printable();
-      printable(const expression& expression);
-      printable(const std::string& msg);
-      printable(const printable_t& printable);
-      printable(const printable& printable);
+      printable(const expression& expression);  // NOLINT(runtime/explicit)
+      printable(const std::string& msg);  // NOLINT(runtime/explicit)
+      printable(const printable_t& printable);  // NOLINT(runtime/explicit)
+      printable(const printable& printable);  // NOLINT(runtime/explicit)
 
       printable_t printable_;
     };
 
     struct is_nil_op : public boost::static_visitor<bool> {
-      bool operator()(const nil& x) const;
-      bool operator()(const int_literal& x) const;
-      bool operator()(const double_literal& x) const;
-      bool operator()(const array_literal& x) const;
-      bool operator()(const variable& x) const;
-      bool operator()(const integrate_ode& x) const;
-      bool operator()(const fun& x) const;
-      bool operator()(const index_op& x) const;
-      bool operator()(const binary_op& x) const;
-      bool operator()(const unary_op& x) const;
-
-      // template <typename T>
-      // bool operator()(const T& x) const;
+      bool operator()(const nil& x) const;  // NOLINT(runtime/explicit)
+      bool operator()(const int_literal& x) const;  // NOLINT(runtime/explicit)
+      bool operator()(const double_literal& x) const;  // NOLINT
+      bool operator()(const array_literal& x) const;  // NOLINT
+      bool operator()(const variable& x) const;  // NOLINT(runtime/explicit)
+      bool operator()(const integrate_ode& x) const;  // NOLINT
+      bool operator()(const fun& x) const;  // NOLINT(runtime/explicit)
+      bool operator()(const index_op& x) const;  // NOLINT(runtime/explicit)
+      bool operator()(const index_op_sliced& x) const;  // NOLINT
+      bool operator()(const binary_op& x) const;  // NOLINT(runtime/explicit)
+      bool operator()(const unary_op& x) const;  // NOLINT(runtime/explicit)
     };
 
     bool is_nil(const expression& e);
@@ -301,8 +303,8 @@ namespace stan {
       int val_;
       expr_type type_;
       int_literal();
-      int_literal(int val);
-      int_literal(const int_literal& il);
+      int_literal(int val);  // NOLINT(runtime/explicit)
+      int_literal(const int_literal& il);  // NOLINT(runtime/explicit)
       int_literal& operator=(const int_literal& il);
     };
 
@@ -311,7 +313,7 @@ namespace stan {
       double val_;
       expr_type type_;
       double_literal();
-      double_literal(double val);
+      double_literal(double val);  // NOLINT(runtime/explicit)
       double_literal& operator=(const double_literal& dl);
     };
 
@@ -319,7 +321,7 @@ namespace stan {
       std::vector<expression> args_;
       expr_type type_;
       array_literal();
-      array_literal(const std::vector<expression>& args);
+      array_literal(const std::vector<expression>& args);  // NOLINT
       array_literal& operator=(const array_literal& al);
     };
 
@@ -327,7 +329,7 @@ namespace stan {
       std::string name_;
       expr_type type_;
       variable();
-      variable(std::string name);
+      variable(std::string name);  // NOLINT(runtime/explicit)
       void set_type(const base_expr_type& base_type,
                     size_t num_dims);
     };
@@ -381,7 +383,6 @@ namespace stan {
       void infer_type();
     };
 
-
     struct binary_op {
       std::string op;
       expression left;
@@ -411,6 +412,81 @@ namespace stan {
       bool has_high() const;
     };
 
+    struct uni_idx {
+      expression idx_;
+      uni_idx();
+      uni_idx(const expression& idx);  // NOLINT(runtime/explicit)
+    };
+    struct multi_idx {
+      expression idxs_;
+      multi_idx();
+      multi_idx(const expression& idxs);  // NOLINT(runtime/explicit)
+    };
+    struct omni_idx {
+      omni_idx();
+    };
+    struct lb_idx {
+      expression lb_;
+      lb_idx();
+      lb_idx(const expression& lb);  // NOLINT(runtime/explicit)
+    };
+    struct ub_idx {
+      expression ub_;
+      ub_idx();
+      ub_idx(const expression& ub);  // NOLINT(runtime/explicit)
+    };
+    struct lub_idx {
+      expression lb_;
+      expression ub_;
+      lub_idx();
+      lub_idx(const expression& lb,
+              const expression& ub);
+    };
+
+    struct idx {
+      typedef boost::variant<boost::recursive_wrapper<uni_idx>,
+                             boost::recursive_wrapper<multi_idx>,
+                             boost::recursive_wrapper<omni_idx>,
+                             boost::recursive_wrapper<lb_idx>,
+                             boost::recursive_wrapper<ub_idx>,
+                             boost::recursive_wrapper<lub_idx> >
+      idx_t;
+
+      idx();
+
+      idx(const uni_idx& i);  // NOLINT(runtime/explicit)
+      idx(const multi_idx& i);  // NOLINT(runtime/explicit)
+      idx(const omni_idx& i);  // NOLINT(runtime/explicit)
+      idx(const lb_idx& i);  // NOLINT(runtime/explicit)
+      idx(const ub_idx& i);  // NOLINT(runtime/explicit)
+      idx(const lub_idx& i);  // NOLINT(runtime/explicit)
+
+      idx_t idx_;
+    };
+
+    struct is_multi_index_vis : public boost::static_visitor<bool> {
+      is_multi_index_vis();
+      bool operator()(const uni_idx& i) const;
+      bool operator()(const multi_idx& i) const;
+      bool operator()(const omni_idx& i) const;
+      bool operator()(const lb_idx& i) const;
+      bool operator()(const ub_idx& i) const;
+      bool operator()(const lub_idx& i) const;
+    };
+
+    bool is_multi_index(const idx& idx);
+
+    struct index_op_sliced {
+      expression expr_;
+      std::vector<idx> idxs_;
+      expr_type type_;
+      index_op_sliced();
+      // vec of vec for e.g., e[1,2][3][4,5,6]
+      index_op_sliced(const expression& expr,
+                      const std::vector<idx>& idxs);
+      void infer_type();
+    };
+
     typedef int var_origin;
     const int model_name_origin = 0;
     const int data_origin = 1;
@@ -433,7 +509,7 @@ namespace stan {
       std::vector<expression> dims_;
       base_expr_type base_type_;
       base_var_decl();
-      base_var_decl(const base_expr_type& base_type);
+      base_var_decl(const base_expr_type& base_type);  // NOLINT
       base_var_decl(const std::string& name,
                     const std::vector<expression>& dims,
                     const base_expr_type& base_type);
@@ -594,19 +670,19 @@ namespace stan {
 
     struct var_decl {
       typedef boost::variant<boost::recursive_wrapper<nil>,
-                     boost::recursive_wrapper<int_var_decl>,
-                     boost::recursive_wrapper<double_var_decl>,
-                     boost::recursive_wrapper<vector_var_decl>,
-                     boost::recursive_wrapper<row_vector_var_decl>,
-                     boost::recursive_wrapper<matrix_var_decl>,
-                     boost::recursive_wrapper<simplex_var_decl>,
-                     boost::recursive_wrapper<unit_vector_var_decl>,
-                     boost::recursive_wrapper<ordered_var_decl>,
-                     boost::recursive_wrapper<positive_ordered_var_decl>,
-                     boost::recursive_wrapper<cholesky_factor_var_decl>,
-                     boost::recursive_wrapper<cholesky_corr_var_decl>,
-                     boost::recursive_wrapper<cov_matrix_var_decl>,
-                     boost::recursive_wrapper<corr_matrix_var_decl> >
+                         boost::recursive_wrapper<int_var_decl>,
+                         boost::recursive_wrapper<double_var_decl>,
+                         boost::recursive_wrapper<vector_var_decl>,
+                         boost::recursive_wrapper<row_vector_var_decl>,
+                         boost::recursive_wrapper<matrix_var_decl>,
+                         boost::recursive_wrapper<simplex_var_decl>,
+                         boost::recursive_wrapper<unit_vector_var_decl>,
+                         boost::recursive_wrapper<ordered_var_decl>,
+                         boost::recursive_wrapper<positive_ordered_var_decl>,
+                         boost::recursive_wrapper<cholesky_factor_var_decl>,
+                         boost::recursive_wrapper<cholesky_corr_var_decl>,
+                         boost::recursive_wrapper<cov_matrix_var_decl>,
+                         boost::recursive_wrapper<corr_matrix_var_decl> >
       var_decl_t;
 
       var_decl_t decl_;
@@ -615,21 +691,21 @@ namespace stan {
 
       // template <typename Decl>
       // var_decl(Decl const& decl);
-      var_decl(const var_decl_t& decl);
-      var_decl(const nil& decl);
-      var_decl(const int_var_decl& decl);
-      var_decl(const double_var_decl& decl);
-      var_decl(const vector_var_decl& decl);
-      var_decl(const row_vector_var_decl& decl);
-      var_decl(const matrix_var_decl& decl);
-      var_decl(const simplex_var_decl& decl);
-      var_decl(const unit_vector_var_decl& decl);
-      var_decl(const ordered_var_decl& decl);
-      var_decl(const positive_ordered_var_decl& decl);
-      var_decl(const cholesky_factor_var_decl& decl);
-      var_decl(const cholesky_corr_var_decl& decl);
-      var_decl(const cov_matrix_var_decl& decl);
-      var_decl(const corr_matrix_var_decl& decl);
+      var_decl(const var_decl_t& decl);  // NOLINT(runtime/explicit)
+      var_decl(const nil& decl);  // NOLINT(runtime/explicit)
+      var_decl(const int_var_decl& decl);  // NOLINT(runtime/explicit)
+      var_decl(const double_var_decl& decl);  // NOLINT(runtime/explicit)
+      var_decl(const vector_var_decl& decl);  // NOLINT(runtime/explicit)
+      var_decl(const row_vector_var_decl& decl);  // NOLINT(runtime/explicit)
+      var_decl(const matrix_var_decl& decl);  // NOLINT(runtime/explicit)
+      var_decl(const simplex_var_decl& decl);  // NOLINT(runtime/explicit)
+      var_decl(const unit_vector_var_decl& decl);  // NOLINT(runtime/explicit)
+      var_decl(const ordered_var_decl& decl);  // NOLINT(runtime/explicit)
+      var_decl(const positive_ordered_var_decl& decl);  // NOLINT
+      var_decl(const cholesky_factor_var_decl& decl);  // NOLINT
+      var_decl(const cholesky_corr_var_decl& decl);  // NOLINT(runtime/explicit)
+      var_decl(const cov_matrix_var_decl& decl);  // NOLINT(runtime/explicit)
+      var_decl(const corr_matrix_var_decl& decl);  // NOLINT(runtime/explicit)
 
       std::string name() const;
     };
@@ -637,6 +713,7 @@ namespace stan {
     struct statement {
       typedef boost::variant<boost::recursive_wrapper<nil>,
                      boost::recursive_wrapper<assignment>,
+                     boost::recursive_wrapper<assgn>,
                      boost::recursive_wrapper<sample>,
                      boost::recursive_wrapper<increment_log_prob_statement>,
                      boost::recursive_wrapper<expression>,
@@ -655,38 +732,40 @@ namespace stan {
       size_t end_line_;
 
       statement();
-      statement(const statement_t& st);
-      statement(const nil& st);
-      statement(const assignment& st);
-      statement(const sample& st);
-      statement(const increment_log_prob_statement& st);
-      statement(const expression& st);
-      statement(const statements& st);
-      statement(const for_statement& st);
-      statement(const conditional_statement& st);
-      statement(const while_statement& st);
-      statement(const print_statement& st);
-      statement(const reject_statement& st);
-      statement(const no_op_statement& st);
-      statement(const return_statement& st);
+      statement(const statement_t& st);  // NOLINT(runtime/explicit)
+      statement(const nil& st);  // NOLINT(runtime/explicit)
+      statement(const assignment& st);  // NOLINT(runtime/explicit)
+      statement(const assgn& st);  // NOLINT(runtime/explicit)
+      statement(const sample& st);  // NOLINT(runtime/explicit)
+      statement(const increment_log_prob_statement& st);  // NOLINT
+      statement(const expression& st);  // NOLINT(runtime/explicit)
+      statement(const statements& st);  // NOLINT(runtime/explicit)
+      statement(const for_statement& st);  // NOLINT(runtime/explicit)
+      statement(const conditional_statement& st);  // NOLINT(runtime/explicit)
+      statement(const while_statement& st);  // NOLINT(runtime/explicit)
+      statement(const print_statement& st);  // NOLINT(runtime/explicit)
+      statement(const reject_statement& st);  // NOLINT(runtime/explicit)
+      statement(const no_op_statement& st);  // NOLINT(runtime/explicit)
+      statement(const return_statement& st);  // NOLINT(runtime/explicit)
 
       bool is_no_op_statement() const;
     };
 
     struct is_no_op_statement_vis : public boost::static_visitor<bool> {
-      bool operator()(const nil& st) const;
-      bool operator()(const assignment& st) const;
-      bool operator()(const sample& st) const;
-      bool operator()(const increment_log_prob_statement& t) const;
-      bool operator()(const expression& st) const;
-      bool operator()(const statements& st) const;
-      bool operator()(const for_statement& st) const;
-      bool operator()(const conditional_statement& st) const;
-      bool operator()(const while_statement& st) const;
-      bool operator()(const print_statement& st) const;
-      bool operator()(const reject_statement& st) const;
-      bool operator()(const no_op_statement& st) const;
-      bool operator()(const return_statement& st) const;
+      bool operator()(const nil& st) const;  // NOLINT(runtime/explicit)
+      bool operator()(const assignment& st) const;  // NOLINT(runtime/explicit)
+      bool operator()(const assgn& st) const;  // NOLINT(runtime/explicit)
+      bool operator()(const sample& st) const;  // NOLINT(runtime/explicit)
+      bool operator()(const increment_log_prob_statement& t) const;  // NOLINT
+      bool operator()(const expression& st) const;  // NOLINT(runtime/explicit)
+      bool operator()(const statements& st) const;  // NOLINT(runtime/explicit)
+      bool operator()(const for_statement& st) const;  // NOLINT
+      bool operator()(const conditional_statement& st) const;  // NOLINT
+      bool operator()(const while_statement& st) const;  // NOLINT
+      bool operator()(const print_statement& st) const;  // NOLINT
+      bool operator()(const reject_statement& st) const;  // NOLINT
+      bool operator()(const no_op_statement& st) const;  // NOLINT
+      bool operator()(const return_statement& st) const;  // NOLINT
     };
 
 
@@ -695,19 +774,20 @@ namespace stan {
       std::ostream& error_msgs_;
       returns_type_vis(const expr_type& return_type,
                        std::ostream& error_msgs);
-      bool operator()(const nil& st) const;
-      bool operator()(const assignment& st) const;
-      bool operator()(const sample& st) const;
-      bool operator()(const increment_log_prob_statement& t) const;
-      bool operator()(const expression& st) const;
-      bool operator()(const statements& st) const;
-      bool operator()(const for_statement& st) const;
-      bool operator()(const conditional_statement& st) const;
-      bool operator()(const while_statement& st) const;
-      bool operator()(const print_statement& st) const;
-      bool operator()(const reject_statement& st) const;
-      bool operator()(const no_op_statement& st) const;
-      bool operator()(const return_statement& st) const;
+      bool operator()(const nil& st) const;  // NOLINT(runtime/explicit)
+      bool operator()(const assignment& st) const;  // NOLINT(runtime/explicit)
+      bool operator()(const assgn& st) const;  // NOLINT(runtime/explicit)
+      bool operator()(const sample& st) const;  // NOLINT(runtime/explicit)
+      bool operator()(const increment_log_prob_statement& t) const;  // NOLINT
+      bool operator()(const expression& st) const;  // NOLINT(runtime/explicit)
+      bool operator()(const statements& st) const;  // NOLINT(runtime/explicit)
+      bool operator()(const for_statement& st) const;  // NOLINT
+      bool operator()(const conditional_statement& st) const;  // NOLINT
+      bool operator()(const while_statement& st) const;  // NOLINT
+      bool operator()(const print_statement& st) const;  // NOLINT
+      bool operator()(const reject_statement& st) const;  // NOLINT
+      bool operator()(const no_op_statement& st) const;  // NOLINT
+      bool operator()(const return_statement& st) const;  // NOLINT
     };
 
     bool returns_type(const expr_type& return_type,
@@ -717,7 +797,7 @@ namespace stan {
     struct increment_log_prob_statement {
       expression log_prob_;
       increment_log_prob_statement();
-      increment_log_prob_statement(const expression& log_prob);
+      increment_log_prob_statement(const expression& log_prob);  // NOLINT
     };
 
     struct for_statement {
@@ -750,19 +830,19 @@ namespace stan {
     struct print_statement {
       std::vector<printable> printables_;
       print_statement();
-      print_statement(const std::vector<printable>& printables);
+      print_statement(const std::vector<printable>& printables);  // NOLINT
     };
 
     struct reject_statement {
       std::vector<printable> printables_;
       reject_statement();
-      reject_statement(const std::vector<printable>& printables);
+      reject_statement(const std::vector<printable>& printables);  // NOLINT
     };
 
     struct return_statement {
       expression return_value_;
       return_statement();
-      return_statement(const expression& expr);
+      return_statement(const expression& expr);  // NOLINT(runtime/explicit)
     };
 
     struct no_op_statement {
@@ -794,7 +874,7 @@ namespace stan {
       function_decl_defs();
 
       function_decl_defs(
-                   const std::vector<function_decl_def>& decl_defs);
+          const std::vector<function_decl_def>& decl_defs);  // NOLINT
 
       std::vector<function_decl_def> decl_defs_;
     };
@@ -804,10 +884,10 @@ namespace stan {
       std::vector<function_decl_def> function_decl_defs_;
       std::vector<var_decl> data_decl_;
       std::pair<std::vector<var_decl>, std::vector<statement> >
-        derived_data_decl_;
+      derived_data_decl_;
       std::vector<var_decl> parameter_decl_;
       std::pair<std::vector<var_decl>, std::vector<statement> >
-        derived_decl_;
+      derived_decl_;
       statement statement_;
       std::pair<std::vector<var_decl>, std::vector<statement> >
       generated_decl_;
@@ -816,13 +896,13 @@ namespace stan {
       program(const std::vector<function_decl_def>& function_decl_defs,
               const std::vector<var_decl>& data_decl,
               const std::pair<std::vector<var_decl>,
-                              std::vector<statement> >& derived_data_decl,
+              std::vector<statement> >& derived_data_decl,
               const std::vector<var_decl>& parameter_decl,
               const std::pair<std::vector<var_decl>,
-                              std::vector<statement> >& derived_decl,
+              std::vector<statement> >& derived_decl,
               const statement& st,
               const std::pair<std::vector<var_decl>,
-                              std::vector<statement> >& generated_decl);
+              std::vector<statement> >& generated_decl);
     };
 
     struct sample {
@@ -844,6 +924,45 @@ namespace stan {
                  expression& expr);
     };
 
+
+    struct var_occurs_vis : public boost::static_visitor<bool> {
+      const std::string var_name_;
+      explicit var_occurs_vis(const variable& e);
+      bool operator()(const nil& e) const;
+      bool operator()(const int_literal& e) const;
+      bool operator()(const double_literal& e) const;
+      bool operator()(const array_literal& e) const;
+      bool operator()(const variable& e) const;
+      bool operator()(const fun& e) const;
+      bool operator()(const integrate_ode& e) const;
+      bool operator()(const index_op& e) const;
+      bool operator()(const index_op_sliced& e) const;
+      bool operator()(const binary_op& e) const;
+      bool operator()(const unary_op& e) const;
+    };
+
+    struct assgn {
+      variable lhs_var_;
+      std::vector<idx> idxs_;
+      expression rhs_;
+      assgn();
+      assgn(const variable& lhs_var, const std::vector<idx>& idxs,
+            const expression& rhs);
+      bool lhs_var_occurs_on_rhs() const;
+    };
+
+    /**
+     * Return the type of the expression indexed by the generalized
+     * index sequence.  Return a type with base type
+     * <code>ILL_FORMED_T</code> if there are too many indexes.
+     *
+     * @param[in] e Expression being indexed.
+     * @param[in] idxs Index sequence.
+     * @return Type of expression applied to indexes.
+     */
+    expr_type indexed_type(const expression& e,
+                           const std::vector<idx>& idxs);
+
     // FIXME:  is this next dependency necessary?
     // from generator.hpp
     void generate_expression(const expression& e, std::ostream& o);
@@ -861,7 +980,7 @@ namespace stan {
 
     struct contains_var : public boost::static_visitor<bool> {
       const variable_map& var_map_;
-      contains_var(const variable_map& var_map);
+      explicit contains_var(const variable_map& var_map);
       bool operator()(const nil& e) const;
       bool operator()(const int_literal& e) const;
       bool operator()(const double_literal& e) const;
@@ -870,6 +989,7 @@ namespace stan {
       bool operator()(const integrate_ode& e) const;
       bool operator()(const fun& e) const;
       bool operator()(const index_op& e) const;
+      bool operator()(const index_op_sliced& e) const;
       bool operator()(const binary_op& e) const;
       bool operator()(const unary_op& e) const;
     };
@@ -880,7 +1000,7 @@ namespace stan {
 
     struct contains_nonparam_var : public boost::static_visitor<bool> {
       const variable_map& var_map_;
-      contains_nonparam_var(const variable_map& var_map);
+      explicit contains_nonparam_var(const variable_map& var_map);
       bool operator()(const nil& e) const;
       bool operator()(const int_literal& e) const;
       bool operator()(const double_literal& e) const;
@@ -889,6 +1009,7 @@ namespace stan {
       bool operator()(const integrate_ode& e) const;
       bool operator()(const fun& e) const;
       bool operator()(const index_op& e) const;
+      bool operator()(const index_op_sliced& e) const;
       bool operator()(const binary_op& e) const;
       bool operator()(const unary_op& e) const;
     };
