@@ -5,6 +5,7 @@
 
 #include <stan/lang/ast.hpp>
 #include <stan/lang/grammars/expression_grammar.hpp>
+#include <stan/lang/grammars/indexes_grammar.hpp>
 #include <stan/lang/grammars/statement_2_grammar.hpp>
 #include <stan/lang/grammars/var_decls_grammar.hpp>
 #include <stan/lang/grammars/whitespace_grammar.hpp>
@@ -32,6 +33,8 @@ namespace stan {
       expression_grammar<Iterator> expression_g;
       var_decls_grammar<Iterator> var_decls_g;
       statement_2_grammar<Iterator> statement_2_g;
+      indexes_grammar<Iterator> indexes_g;
+
 
       // rules
       boost::spirit::qi::rule<Iterator,
@@ -39,6 +42,11 @@ namespace stan {
                               whitespace_grammar<Iterator> >
       assignment_r;
 
+      boost::spirit::qi::rule<Iterator,
+                              assgn(var_origin),
+                              whitespace_grammar<Iterator> >
+      assgn_r;
+
       boost::spirit::qi::rule<Iterator,
                               expression(var_origin),
                               whitespace_grammar<Iterator> >
@@ -50,6 +58,11 @@ namespace stan {
                               whitespace_grammar<Iterator> >
       dims_r;
 
+      boost::spirit::qi::rule<Iterator,
+                              variable(var_origin),
+                              whitespace_grammar<Iterator> >
+      var_r;
+
 
       boost::spirit::qi::rule<Iterator,
                               distribution(var_origin),
