@@ -5,6 +5,7 @@
 
 #include <stan/lang/ast.hpp>
 #include <stan/lang/grammars/expression_grammar.hpp>
+#include <stan/lang/grammars/indexes_grammar.hpp>
 #include <stan/lang/grammars/whitespace_grammar.hpp>
 
 #include <string>
@@ -21,6 +22,9 @@ namespace stan {
     template <typename Iterator>
     struct expression_grammar;
 
+    template <typename Iterator>
+    struct indexes_grammar;
+
     template <typename Iterator>
     struct term_grammar
       : public boost::spirit::qi::grammar<Iterator,
@@ -31,9 +35,12 @@ namespace stan {
                    expression_grammar<Iterator>& eg);
 
       variable_map& var_map_;
+
       std::stringstream& error_msgs_;
 
-      stan::lang::expression_grammar<Iterator>& expression_g;
+      expression_grammar<Iterator>& expression_g;
+
+      indexes_grammar<Iterator> indexes_g;
 
       boost::spirit::qi::rule<Iterator,
                               std::vector<expression>(var_origin),
@@ -81,13 +88,12 @@ namespace stan {
                               whitespace_grammar<Iterator> >
       identifier_r;
 
-
       boost::spirit::qi::rule<Iterator,
-                              expression(var_origin),
- boost::spirit::qi::locals<std::vector<std::vector<stan::lang::expression> > >,
-                              whitespace_grammar<Iterator> >
-      indexed_factor_r;
-
+          expression(var_origin),
+          boost::spirit::qi::locals<std::vector<std::vector<expression> >,
+                                    std::vector<idx> >,
+          whitespace_grammar<Iterator> >
+      idx_factor_r;
 
       boost::spirit::qi::rule<Iterator,
                               int_literal(),
