@@ -4,7 +4,6 @@
 #include <stan/mcmc/hmc/hamiltonians/ps_point.hpp>
 
 namespace stan {
-
   namespace mcmc {
 
     // Point in a phase space with a base
@@ -22,20 +21,18 @@ namespace stan {
         fast_vector_copy_<double>(mInv, z.mInv);
       }
 
-      void write_metric(std::ostream* o) {
-        if (!o)
-          return;
-
-        *o << "# Diagonal elements of inverse mass matrix:" << std::endl;
-        *o << "# " << mInv(0) << std::flush;
+      void
+      write_metric(stan::interface_callbacks::writer::base_writer& writer) {
+        writer("# Diagonal elements of inverse mass matrix:");
+        std::stringstream mInv_ss;
+        mInv_ss << "# " << mInv(0);
         for (int i = 1; i < mInv.size(); ++i)
-          *o << ", " << mInv(i) << std::flush;
-        *o << std::endl;
+          mInv_ss << ", " << mInv(i);
+        writer(mInv_ss.str());
       }
     };
 
   }  // mcmc
-
 }  // stan
 
 #endif
