@@ -4,23 +4,23 @@
 #include <ostream>
 
 namespace stan {
-
   namespace mcmc {
 
-    template <typename H, typename P>
+    template <typename Hamiltonian>
     class base_integrator {
     public:
       explicit base_integrator(std::ostream* o)
         : out_stream_(o) {}
 
-      virtual void evolve(P& z, H& hamiltonian, const double epsilon) = 0;
+      virtual void evolve(typename Hamiltonian::PointType& z,
+                          Hamiltonian& hamiltonian,
+                          const double epsilon) = 0;
 
     protected:
       std::ostream* out_stream_;
     };
 
   }  // mcmc
-
 }  // stan
 
 #endif
