@@ -27,12 +27,13 @@ namespace stan {
 
     // The No-U-Turn Sampler (NUTS).
 
-    template <class M, class P, template<class, class> class H,
-              template<class, class> class I, class BaseRNG>
-    class base_nuts: public base_hmc<M, P, H, I, BaseRNG> {
+    template <class Model, template<class, class> class Hamiltonian,
+              template<class> class Integrator, class BaseRNG>
+    class base_nuts : public base_hmc<Model, Hamiltonian, Integrator, BaseRNG> {
     public:
-      base_nuts(M &m, BaseRNG& rng, std::ostream* o, std::ostream* e)
-        : base_hmc<M, P, H, I, BaseRNG>(m, rng, o, e),
+      base_nuts(Model &model, BaseRNG& rng,
+                std::ostream* o, std::ostream* e)
+        : base_hmc<Model, Hamiltonian, Integrator, BaseRNG>(model, rng, o, e),
         depth_(0), max_depth_(5), max_delta_(1000),
         n_leapfrog_(0), n_divergent_(0) {
       }
@@ -168,7 +169,9 @@ namespace stan {
         values.push_back(this->n_divergent_);
       }
 
-      virtual bool compute_criterion(ps_point& start, P& finish,
+      virtual bool compute_criterion(ps_point& start,
+                                     typename Hamiltonian<Model, BaseRNG>
+                                     ::PointType& finish,
                                      Eigen::VectorXd& rho) = 0;
 
       // Returns number of valid points in the completed subtree
