@@ -13,15 +13,15 @@ namespace stan {
     // Hamiltonian Monte Carlo on a
     // Euclidean manifold with diagonal metric
     // and static integration time
-    template <typename M, class BaseRNG>
+    template <typename Model, class BaseRNG>
     class diag_e_static_hmc
-      : public base_static_hmc<M, diag_e_point, diag_e_metric,
+      : public base_static_hmc<Model, diag_e_metric,
                                expl_leapfrog, BaseRNG> {
     public:
-      diag_e_static_hmc(M &m, BaseRNG& rng,
+      diag_e_static_hmc(Model &model, BaseRNG& rng,
                         std::ostream* o, std::ostream* e)
-        : base_static_hmc<M, diag_e_point, diag_e_metric,
-                          expl_leapfrog, BaseRNG>(m, rng, o, e) {
+        : base_static_hmc<Model, diag_e_metric,
+                          expl_leapfrog, BaseRNG>(model, rng, o, e) {
         this->name_ = "Static HMC with a diagonal Euclidean metric";
       }
     };
