@@ -1,11 +1,10 @@
 #ifndef STAN_MODEL_PROB_GRAD_HPP
 #define STAN_MODEL_PROB_GRAD_HPP
 
+#include <stan/io/csv_writer.hpp>
 #include <utility>
 #include <vector>
 
-#include <stan/io/csv_writer.hpp>
-
 namespace stan {
 
   namespace model {
@@ -16,21 +15,18 @@ namespace stan {
      * Models extending this base helper class.
      */
     class prob_grad {
-
     protected:
-
       size_t num_params_r__;
-      std::vector<std::pair<int,int> > param_ranges_i__;
+      std::vector<std::pair<int, int> > param_ranges_i__;
 
     public:
-
-      prob_grad(size_t num_params_r)
+      explicit prob_grad(size_t num_params_r)
         : num_params_r__(num_params_r),
-          param_ranges_i__(std::vector<std::pair<int,int> >(0)) {
+          param_ranges_i__(std::vector<std::pair<int, int> >(0)) {
       }
 
       prob_grad(size_t num_params_r,
-                std::vector<std::pair<int,int> >& param_ranges_i)
+                std::vector<std::pair<int, int> >& param_ranges_i)
         : num_params_r__(num_params_r),
           param_ranges_i__(param_ranges_i) {
       }
@@ -45,10 +41,9 @@ namespace stan {
         return param_ranges_i__.size();
       }
 
-      inline std::pair<int,int> param_range_i(size_t idx) const {
+      inline std::pair<int, int> param_range_i(size_t idx) const {
         return param_ranges_i__[idx];
       }
-
     };
   }
 }
