@@ -2,8 +2,8 @@
 #define STAN_SERVICES_MCMC_WARMUP_HPP
 
 #include <stan/mcmc/base_mcmc.hpp>
-#include <stan/io/mcmc_writer.hpp>
-#include <stan/services/mcmc/run_markov_chain.hpp>
+#include <stan/services/sample/mcmc_writer.hpp>
+#include <stan/services/sample/generate_transitions.hpp>
 #include <string>
 
 namespace stan {
@@ -19,9 +19,9 @@ namespace stan {
                   int num_thin,
                   int refresh,
                   bool save,
-                  stan::io::mcmc_writer<
-                    Model, SampleRecorder, DiagnosticRecorder, MessageRecorder>&
-                    writer,
+                  stan::services::sample::mcmc_writer<
+                  Model, SampleRecorder, DiagnosticRecorder, MessageRecorder>&
+                  writer,
                   stan::mcmc::sample& init_s,
                   Model& model,
                   RNG& base_rng,
@@ -29,8 +29,9 @@ namespace stan {
                   const std::string& suffix,
                   std::ostream& o,
                   StartTransitionCallback& callback) {
-        run_markov_chain<Model, RNG, StartTransitionCallback,
-                         SampleRecorder, DiagnosticRecorder, MessageRecorder>
+        sample::generate_transitions<Model, RNG, StartTransitionCallback,
+                                     SampleRecorder, DiagnosticRecorder,
+                                     MessageRecorder>
           (sampler, num_warmup, 0, num_warmup + num_samples, num_thin,
            refresh, save, true,
            writer,
